require 'xvfb'
require 'selenium-webdriver'

describe 'Integration test' do
  let!(:xvfb) { xvfb.new }
  before { xvfb.start }

  after { xvfb.destroy_sync }

  it 'should use xvfb' do
    work_with_browser
  end

  it 'should record video with ffmpeg' do
    xvfb.video.start_capture
    work_with_browser
    xvfb.video.stop_and_save("test.mov")
    expect(File.exist?("test.mov")).to eq true
  end

  it 'should raise an error when trying to create the same display' do
    expect {
      FileUtils.mv("/tmp/.X#{xvfb.display}-lock", "/tmp/xvfb-test-tmp")
      xvfb.new(display: xvfb.display, reuse: false)
    }.to raise_error(Xvfb::Exception, /troubleshooting guide/)
    FileUtils.mv("/tmp/xvfb-test-tmp", "/tmp/.X#{xvfb.display}-lock")
  end

  private

  def work_with_browser
    driver = Selenium::WebDriver.for :firefox
    driver.navigate.to 'http://google.com'
    expect(driver.title).to match(/Google/)
    driver.close
  end
end
